@@ -1,6 +1,6 @@
 /*
     This file is part of libkabc.
-    Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -29,8 +29,7 @@
 /** @short Class that holds a IMPP for a contact.
  *  @since 4.14.5
  */
-namespace KContacts
-{
+namespace KContacts {
 class KCONTACTS_EXPORT Impp
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Impp &);
@@ -61,25 +60,25 @@ public:
         Facebook = 14,
         EndList
     };
-    bool isValid() const;
+    Q_REQUIRED_RESULT bool isValid() const;
 
-    ImppType type() const;
+    Q_REQUIRED_RESULT ImppType type() const;
     void setType(ImppType type);
 
     void setAddress(const QString &address);
-    QString address() const;
+    Q_REQUIRED_RESULT QString address() const;
 
     void setParameters(const QMap<QString, QStringList> &params);
-    QMap<QString, QStringList> parameters() const;
+    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
 
-    bool operator==(const Impp &other) const;
-    bool operator!=(const Impp &other) const;
+    Q_REQUIRED_RESULT bool operator==(const Impp &other) const;
+    Q_REQUIRED_RESULT bool operator!=(const Impp &other) const;
 
     Impp &operator=(const Impp &other);
 
-    QString toString() const;
+    Q_REQUIRED_RESULT QString toString() const;
 
-    static QString typeToString(ImppType type);
+    Q_REQUIRED_RESULT static QString typeToString(ImppType type);
 
 private:
     class Private;
@@ -89,7 +88,6 @@ private:
 KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const Impp &object);
 
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, Impp &object);
-
 }
 
 Q_DECLARE_TYPEINFO(KContacts::Impp, Q_MOVABLE_TYPE);
