@@ -45,20 +45,20 @@ public:
 
     typedef QVector<ResourceLocatorUrl> List;
 
-    bool isValid() const;
+    Q_REQUIRED_RESULT bool isValid() const;
 
     void setUrl(const QUrl &url);
-    QUrl url() const;
+    Q_REQUIRED_RESULT QUrl url() const;
 
     void setParameters(const QMap<QString, QStringList> &params);
-    QMap<QString, QStringList> parameters() const;
+    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
 
-    bool operator==(const ResourceLocatorUrl &other) const;
-    bool operator!=(const ResourceLocatorUrl &other) const;
+    Q_REQUIRED_RESULT bool operator==(const ResourceLocatorUrl &other) const;
+    Q_REQUIRED_RESULT bool operator!=(const ResourceLocatorUrl &other) const;
 
     ResourceLocatorUrl &operator=(const ResourceLocatorUrl &other);
 
-    QString toString() const;
+    Q_REQUIRED_RESULT QString toString() const;
 private:
     class Private;
     QSharedDataPointer<Private> d;
